/**
 * Makes request to Jupyter Comments API
 *
 * @export
 * @async
 * @template T
 * @param {string} [endPoint=''] API endpoint
 * @param {RequestInit} [init={}]
 * @returns {Promise<T>}
 */
export declare function requestAPI<T>(endPoint?: string, init?: RequestInit): Promise<T>;
/**
 * Function to send new comment data to the API and calls
 * a function that updates interface on a successfull call
 *
 * @param {string} commentId, id of a comment, '' if it is a new comment
 * @param {string} filePath, full path of a file that was commented on
 * @param {string} cellId, id of a cell if comment is linked to a notebook, '' otherwise
 * @param {number} editorLine, line number if comment is lined to an editor, '' otherwise
 * @param {string} editorLineText, text for the line commented in an editor, '' otherwise
 * @param {string} username, system username of user that created a comment
 * @param {string} text, comment text
 * @param {number} resolved, is comment resolved
 * @param {string} parentId, comment parentId if it is a reply, '' otherwise
 * @param {() => void} updateComments, function that pulls comments from db and rerenders inteface
 * @returns {void) => void}
 */
export declare const updateComment: (commentId: string, filePath: string, cellId: string, editorLine: number, editorLineText: string, username: string, text: string, resolved: number, parentId: string, updateComments: () => void) => void;
